@@ -24,7 +24,7 @@ import logging
 from datetime import date
 
 from PyQt5.QtGui import QIcon, QPixmap, QFontMetrics
-from PyQt5.QtCore import Qt, QSize, pyqtSlot
+from PyQt5.QtCore import Qt, pyqtSlot
 from PyQt5.QtWidgets import (
     QDialog,
     QHBoxLayout,
@@ -35,8 +35,7 @@ from PyQt5.QtWidgets import (
     QProgressBar,
     QPushButton,
     QApplication,
-    QGridLayout,
-    QMessageBox
+    QGridLayout
 )
 
 import venvipy_rc  # pylint: disable=unused-import
@@ -53,7 +52,7 @@ logger = logging.getLogger(__name__)
 
 class ProgBarDialog(QDialog):
     """
-    Dialog showing a progress bar during the create process.
+    Dialog showing a progress bar during processes.
     """
     def __init__(self):
         super().__init__()
@@ -102,8 +101,8 @@ class ProgBarDialog(QDialog):
 
 class ConsoleDialog(QDialog):
     """
-    Dialog box printing the output to a console-like widget during the
-    installation process.
+    Dialog box printing the output to a console-like widget when running
+    commands.
     """
     def __init__(self):
         super().__init__()
@@ -112,7 +111,7 @@ class ConsoleDialog(QDialog):
 
 
     def initUI(self):
-        self.resize(910, 555)
+        self.resize(1115, 705)
         self.center()
         self.setWindowIcon(QIcon(":/img/profile.png"))
         self.setWindowFlag(Qt.WindowCloseButtonHint, False)
@@ -158,18 +157,6 @@ class ConsoleDialog(QDialog):
         self.console_window.append(formatted_text)
 
 
-    def finish_fail(self):
-        """
-        Show info message when the installation process failed.
-        """
-        message_txt = (
-            "Could not install from requirements.\n\n"
-            "File not found.\n"
-        )
-        logger.error("Could not install from requirements")
-        QMessageBox.critical(self, "Error", message_txt)
-
-
 
 #]===========================================================================[#
 #] APPLICATION INFO DIALOG [#================================================[#
@@ -187,7 +174,7 @@ class InfoAboutVenviPy(QDialog):
 
     def initUI(self):
         self.setWindowTitle("About VenviPy")
-        self.setFixedSize(495, 395)
+        self.setFixedSize(500, 405)
         self.center()
         self.setWindowIcon(QIcon(":/img/profile.png"))
         self.setWindowFlag(Qt.WindowMinimizeButtonHint, False)
@@ -195,10 +182,11 @@ class InfoAboutVenviPy(QDialog):
         # logo
         logo = QLabel()
         pixmap = QPixmap(":/img/default.png")
-        logo_scaled = pixmap.scaled(140, 140, Qt.KeepAspectRatio)
+        logo_scaled = pixmap.scaled(156, 156, Qt.KeepAspectRatio)
         logo.setPixmap(logo_scaled)
 
-        place_holder_1 = QLabel(maximumHeight=1)
+        # add some space
+        place_holder_1 = QLabel(minimumHeight=1)
 
         # title
         title_label = QLabel(
@@ -229,6 +217,7 @@ class InfoAboutVenviPy(QDialog):
             </a></span></p>',
             openExternalLinks=True
         )
+        repo_label.setToolTip("https://github.com/sinusphi/venvipy")
 
         # copyright
         current_year = str(date.today().year)
@@ -238,30 +227,13 @@ class InfoAboutVenviPy(QDialog):
             </span></p>'
         )
 
-        place_holder_2 = QLabel(maximumHeight=15)
-
-        disclaimer_label_1 = QLabel(
-            '<p><span style="font-size:10pt;">\
-                This program comes WITHOUT ANY WARRANTY.\
-            </span></p>',
-        )
-
-        disclaimer_label_2 = QLabel(
-            '<p><span style="font-size:10pt;">\
-                Visit the \
-                <a href="https://www.gnu.org/licenses/licenses.en.html#GPL">\
-                GNU General Public License, version 3 or later</a> \
-                for more information.\
-            </span></p>',
-            openExternalLinks=True
-        )
+        place_holder_2 = QLabel(minimumHeight=5)
 
         # close button
         close_button = QPushButton("Close", clicked=self.close)
         close_button.setFixedWidth(135)
         close_button.setFixedHeight(30)
 
-
         # layout
         grid_layout = QGridLayout(self)
         grid_layout.setContentsMargins(15, 15, 10, 15)
@@ -273,12 +245,8 @@ class InfoAboutVenviPy(QDialog):
         grid_layout.addWidget(subtitle_label, 4, 0, Qt.AlignHCenter)
         grid_layout.addWidget(repo_label, 5, 0, Qt.AlignHCenter)
         grid_layout.addWidget(copyright_label, 6, 0, Qt.AlignHCenter)
-
         grid_layout.addWidget(place_holder_2, 7, 0, Qt.AlignHCenter)
-        grid_layout.addWidget(disclaimer_label_1, 8, 0, Qt.AlignHCenter)
-        grid_layout.addWidget(disclaimer_label_2, 9, 0, Qt.AlignHCenter)
-
-        grid_layout.addWidget(close_button, 10, 0, Qt.AlignRight)
+        grid_layout.addWidget(close_button, 8, 0, Qt.AlignRight)
         self.setLayout(grid_layout)
 
 
